{ config
, lib
, pkgs
, ...
}: {
  boot = {
    initrd.availableKernelModules = [ "amdgpu" ];
    kernelModules = [ "amdgpu" ];
    # kernelParams = [ "amdgpu.ppfeaturemask=0xffffffff" ];
  };

  programs.corectrl = {
    enable = true;
    gpuOverclock.enable = true;
  };

  # services.xserver.videoDrivers = [ "amdgpu" ];
  services.xserver.videoDrivers = lib.mkDefault [ "modesetting" ];

  systemd.tmpfiles.rules = [
    "L+    /opt/rocm/hip	-    -    -     -    ${pkgs.rocmPackages_5.clr}"
    "L+    /opt/rocm/rocblas	-    -    -     -    ${pkgs.rocmPackages_5.rocblas}"
    "L+    /opt/rocm/hipblas	-    -    -     -    ${pkgs.rocmPackages_5.hipblas}"
    "L+    /opt/rocm/clang	-    -    -     -    ${pkgs.rocmPackages_5.llvm.clang}"
    "L+    /opt/rocm/runtime	-    -    -     -    ${pkgs.rocmPackages_5.rocm-runtime}"
  ];
  hardware.opengl = {
    driSupport = true;
    driSupport32Bit = true;
    extraPackages = with pkgs; [
      amdvlk
      rocmPackages_5.rocm-runtime
      rocmPackages_5.llvm.clang
      rocm-opencl-icd
      rocm-opencl-runtime
      vaapiVdpau
      libvdpau-va-gl
      # libva1
      obs-studio-plugins.obs-vaapi # TODO check if obs is enabled
      gst_all_1.gstreamer
      gst_all_1.gst-vaapi
    ];
    extraPackages32 = with pkgs; [
      driversi686Linux.amdvlk
      driversi686Linux.vaapiVdpau
      driversi686Linux.libvdpau-va-gl
    ];
  };

  # Force radv
  environment.variables.AMD_VULKAN_ICD = "RADV";
  environment.systemPackages = with pkgs; [
    vulkan-tools
    libva-utils
    glxinfo # TODO right place here or in desktop ?
    clinfo
    wayland-utils # TODO move somewhere better ?
    # nixgl.nixGLIntel
    # nixgl.nixVulkanIntel
  ];
}
